IteratorExt

Trait IteratorExt 

pub trait IteratorExt {
    // Required methods
    fn transpose_into_fallible<T, E>(self) -> Convert<Self>
       where Self: Iterator<Item = Result<T, E>> + Sized;
    fn into_fallible<T>(self) -> IntoFallible<Self>
       where Self: Iterator<Item = T> + Sized;
}
An extnsion-trait with set of useful methods to convert core::iter::Iterator into FallibleIterator

Required Methods

fn transpose_into_fallible<T, E>(self) -> Convert<Self>
where Self: Iterator<Item = Result<T, E>> + Sized,

Convert an iterator of Results into FallibleIterator by transposition

fn into_fallible<T>(self) -> IntoFallible<Self>
where Self: Iterator<Item = T> + Sized,

Convert an iterator of anything into FallibleIterator by wrapping into Result<T, Infallible> where Infallible is an error that can never actually happen.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I> IteratorExt for I
where I: Iterator,